.. -*- mode: rst -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:

.. _chap_cmdline:

**********************
Command line reference
**********************

Main command
============

.. toctree::
   :maxdepth: 1

   generated/man/niceman

Environments operations
=======================

.. toctree::
   :maxdepth: 1

   generated/man/niceman-ls
   generated/man/niceman-create
   generated/man/niceman-install
   generated/man/niceman-delete
   generated/man/niceman-start
   generated/man/niceman-stop
   generated/man/niceman-login

Miscellaneous commands
======================

.. toctree::
   :maxdepth: 1

   generated/man/niceman-retrace
   generated/man/niceman-test
